==> dbio-1.0.0.tar.gz: lib/src/TopUserDetails.dart <==
class TopUserDetails {
  int id;
  User user;
  Discord discord;

  TopUserDetails({this.id, this.user, this.discord});

  TopUserDetails.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    discord =
        json['discord'] != null ? new Discord.fromJson(json['discord']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    if (this.user != null) {
      data['user'] = this.user.toJson();
    }
    if (this.discord != null) {
      data['discord'] = this.discord.toJson();
    }
    return data;
  }
}

class User {
  String userId;
  int upvotes;
  String description;
  int verified;
  int premiumStatus;
  String name;

  User(
      {this.userId,
      this.upvotes,
      this.description,
      this.verified,
      this.premiumStatus,
      this.name});

  User.fromJson(Map<String, dynamic> json) {
    userId = json['user_id'];
    upvotes = json['upvotes'];
    description = json['description'];
    verified = json['verified'];
    premiumStatus = json['premium_status'];
    name = json['name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['user_id'] = this.userId;
    data['upvotes'] = this.upvotes;
    data['description'] = this.description;
    data['verified'] = this.verified;
    data['premium_status'] = this.premiumStatus;
    data['name'] = this.name;
    return data;
  }
}

class Discord {
  String id;
  String username;
  String avatar;
  String discriminator;

  Discord({this.id, this.username, this.avatar, this.discriminator});

  Discord.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    username = json['username'];
    avatar = json['avatar'];
    discriminator = json['discriminator'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['username'] = this.username;
    data['avatar'] = this.avatar;
    data['discriminator'] = this.discriminator;
    return data;
  }
}

==> dbio-1.0.1.tar.gz: lib/src/TopUserDetails.dart <==
class TopUserDetails {
  int id;
  User user;
  Discord discord;

  TopUserDetails({this.id, this.user, this.discord});

  TopUserDetails.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    user = json['user'] != null ? User.fromJson(json['user']) : null;
    discord =
        json['discord'] != null ? Discord.fromJson(json['discord']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    if (this.user != null) {
      data['user'] = this.user.toJson();
    }
    if (this.discord != null) {
      data['discord'] = this.discord.toJson();
    }
    return data;
  }
}

class User {
  String userId;
  int upvotes;
  String description;
  int verified;
  int premiumStatus;
  String name;

  User(
      {this.userId,
      this.upvotes,
      this.description,
      this.verified,
      this.premiumStatus,
      this.name});

  User.fromJson(Map<String, dynamic> json) {
    userId = json['user_id'];
    upvotes = json['upvotes'];
    description = json['description'];
    verified = json['verified'];
    premiumStatus = json['premium_status'];
    name = json['name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['user_id'] = this.userId;
    data['upvotes'] = this.upvotes;
    data['description'] = this.description;
    data['verified'] = this.verified;
    data['premium_status'] = this.premiumStatus;
    data['name'] = this.name;
    return data;
  }
}

class Discord {
  String id;
  String username;
  String avatar;
  String discriminator;

  Discord({this.id, this.username, this.avatar, this.discriminator});

  Discord.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    username = json['username'];
    avatar = json['avatar'];
    discriminator = json['discriminator'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['username'] = this.username;
    data['avatar'] = this.avatar;
    data['discriminator'] = this.discriminator;
    return data;
  }
}
